@@ -1,5 +1,5 @@
 package ExtUtils::Typemaps::Magic;
-$ExtUtils::Typemaps::Magic::VERSION = '0.001';
+$ExtUtils::Typemaps::Magic::VERSION = '0.002';
 use strict;
 use warnings;
 
@@ -42,6 +42,10 @@ END
 	return $self;
 }
 
+sub minimum_pxs {
+	return '3.50';
+}
+
 1;
 
 # ABSTRACT: Typemap for storing objects in magic
@@ -58,7 +62,7 @@ ExtUtils::Typemaps::Magic - Typemap for storing objects in magic
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
